@@ -1,7 +1,7 @@
 from time import time
 from urllib.parse import urlencode
-from typing import TypedDict, Optional, Mapping, Union, Any
-
+from typing import Optional, Mapping, Union, Any
+from typing_extensions import TypedDict
 
 class FlayyerMeta(TypedDict, total=False):
     agent: str
@@ -50,6 +50,9 @@ class Flayyer:
             return f"https://flayyer.io/v2/{self.tenant}/{self.deck}/{self.template}.{self.version}.{self.extension}?{query}"
         return f"https://flayyer.io/v2/{self.tenant}/{self.deck}/{self.template}.{self.extension}?{query}"
 
+    def __str__(self):
+        return self.href()
+
 
 # From https://stackoverflow.com/a/43347067/3416691
 # Alternative: https://stackoverflow.com/a/4014164/3416691
@@ -59,7 +62,7 @@ def to_query(params: Mapping[Any, Any]) -> str:
     def _encode_params(params, p_key=None):
         encode_params = {}
         if params is None:
-            g_encode_params[p_key] = ""  # Empty
+            pass # skip
         elif isinstance(params, dict):
             for key in params:
                 encode_key = "{}[{}]".format(p_key, key)
